def add(a: int, b: int) -> int:
    return a + b

def multiply(a: int, b: int) -> int:
    return a * b

def subtract(a: int, b: int) -> int:
    return a - b

def division(a: int, b: int) -> float:
    return a / b



from .core import add, multiply, subtract, division, upper
from .utils import greet
from .version import __version__

__all__ = ["add", "multiply", "subtract", "division", "upper", "greet", "__version__"]
